@@ -1,4 +1,5 @@
 from sym.cli.helpers.os import find_command
+from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
 from ...errors import SAMLClientNotFound
 from ..config import Config
@@ -27,7 +28,7 @@ class DependenciesCheck(SymCheck):
 class ResourceCheck(SymCheck):
     def check(self, ctx: CheckContext) -> CheckResult:
         try:
-            client = ctx.options.create_saml_client(ctx.resource)
+            client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
             msg = f"Created client with {client.binary} for resource {ctx.resource}"
             msg += "\nUsing config: " + str(client.config_file.path)
             msg += "\n" + client.config_file.read()
