@@ -128,14 +128,14 @@ class SymUpdater:
             return
         self._log(f"found newer version {self.latest_version}!", fg="white", bold=True)
 
-        self._log("Updating...", nl=False)
+        self._log("Updating...")
         if self._update():
-            self._log("finished!", fg="green")
+            self._log("Update finished!", fg="green")
             if replace:
                 reset_fds()
                 os.execvp(sys.argv[0], sys.argv)
         else:
-            self._log("failed :(", fg="red")
+            self._log("Update failed :(", fg="red")
 
     def auto_update(self):
         try:
